@@ -8,8 +8,10 @@ from sqlalchemy import Column, Integer, String, create_engine
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker
 import os
+import shutil
 
 Base = declarative_base()
+sqlite_db_name = "leyenorden.db"
 
 class Client(Base):
     __tablename__ = 'clients'
@@ -33,6 +35,7 @@ class Client(Base):
     def __repr__(self):
         return "<Client('%s','%s','%s')>" % \
                 (self.dni, self.name, self.surname)
+
 def insert_test(session):
         clients = session.query(Client).all()
         if len(clients) == 0:
@@ -42,14 +45,14 @@ def insert_test(session):
             a = [client1,client2,client3]
             session.add_all(a)
             session.commit()
-            print 'Inserted 3 test clients'
+            return True
                 
 def get_session(user = None, password = None, echo=False, sqlite=True):
     if sqlite:
-        ordenpath = os.path.expanduser('~/.ordeneley')
+        ordenpath = os.path.expanduser('~/.ordenley')
         if not os.path.exists(ordenpath):
             os.makedirs(ordenpath)
-        engine = create_engine("sqlite:///%s/leyenorden.db" % ordenpath, echo=echo)
+        engine = create_engine("sqlite:///%s/%s" % (ordenpath, sqlite_db_name), echo=echo)
     else:
         engine = create_engine("mysql://"+user+":"+password+"@localhost/leyenorden" , echo=echo)
     Base.metadata.create_all(engine)
@@ -57,10 +60,21 @@ def get_session(user = None, password = None, echo=False, sqlite=True):
 
 
 def delete_first_test(session):
-    client = session.query(Client).one()
+    client = session.query(Client).first()
     session.delete(client)
     session.commit()
-    print 'deleted' + str(client)
+    return True
+
+def delete_sqlite_db(session):
+    """Delete db from software"""
+    db_path = os.path.expanduser('~/.ordenley/')
+    shutil.rmtree(db_path)
+
+def main():
+    """main function to test this module"""
+    session = get_session()
+    insert_test(session)
+    
 
 if __name__ == '__main__':
 #    Before use this module you should create a user and password plus create a database
@@ -70,5 +84,4 @@ if __name__ == '__main__':
 #    mysql> create database leyenorden;
 #    mysql> grant all on ordenley.* to leyuser@localhost identified by 'pass';
 #    engine = create_engine("mysql://leyuser:pass@localhost/ordenley", echo=True)
-    session = get_session()
-    insert_test(session)
+    self.main()
